@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdfeed.cpp,v 1.7 2008/09/26 17:52:22 fredg Exp $
+//      $Id: rdfeed.cpp,v 1.7.2.3 2009/02/05 19:50:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -182,6 +182,19 @@ void RDFeed::setBaseUrl(const QString &str) const
 }
 
 
+QString RDFeed::basePreamble() const
+{
+  return RDGetSqlValue("FEEDS","KEY_NAME",feed_keyname,"BASE_PREAMBLE").
+    toString();
+}
+
+
+void RDFeed::setBasePreamble(const QString &str) const
+{
+  SetRow("BASE_PREAMBLE",str);
+}
+
+
 QString RDFeed::purgeUrl() const
 {
   return RDGetSqlValue("FEEDS","KEY_NAME",feed_keyname,"PURGE_URL").
@@ -260,6 +273,19 @@ void RDFeed::setItemXml(const QString &str)
 }
 
 
+bool RDFeed::castOrder() const
+{
+  return RDBool(RDGetSqlValue("FEEDS","KEY_NAME",feed_keyname,
+			      "CAST_ORDER").toString());
+}
+
+
+void RDFeed::setCastOrder(bool state) const
+{
+  SetRow("CAST_ORDER",RDYesNo(state));
+}
+
+
 int RDFeed::maxShelfLife() const
 {
   return RDGetSqlValue("FEEDS","KEY_NAME",feed_keyname,"MAX_SHELF_LIFE").toInt();
@@ -428,6 +454,19 @@ void RDFeed::setNormalizeLevel(int lvl) const
 }
 
 
+QString RDFeed::redirectPath() const
+{
+  return RDGetSqlValue("FEEDS","KEY_NAME",feed_keyname,"REDIRECT_PATH").
+    toString();
+}
+
+
+void RDFeed::setRedirectPath(const QString &str)
+{
+  SetRow("REDIRECT_PATH",str);
+}
+
+
 void RDFeed::SetRow(const QString &param,int value) const
 {
   RDSqlQuery *q;
