@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_endpoints.cpp,v 1.13 2007/09/14 14:06:27 fredg Exp $
+//      $Id: list_endpoints.cpp,v 1.15 2007/10/23 18:21:57 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,11 +25,10 @@
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 
 #include <rd.h>
 #include <rdpasswd.h>
-
+#include <rddb.h>
 #include <edit_user.h>
 #include <list_endpoints.h>
 #include <edit_endpoint.h>
@@ -40,7 +39,7 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QListViewItem *l;
   QString str;
 
@@ -101,40 +100,58 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
   list_list_view->addColumn(tr("LABEL"));
   list_list_view->setColumnAlignment(1,Qt::AlignLeft);
   switch(matrix->type()) {
-      case RDMatrix::Unity4000:
-	if(list_endpoint==RDMatrix::Input) {
-	  list_list_view->addColumn(tr("SOURCE"));
-	  list_list_view->setColumnAlignment(2,Qt::AlignHCenter);
-	  list_list_view->addColumn(tr("MODE"));
-	  list_list_view->setColumnAlignment(3,Qt::AlignHCenter);
-	}
-	break;
+    case RDMatrix::Unity4000:
+      list_readonly=false;
+      if(list_endpoint==RDMatrix::Input) {
+	list_list_view->addColumn(tr("SOURCE"));
+	list_list_view->setColumnAlignment(2,Qt::AlignHCenter);
+	list_list_view->addColumn(tr("MODE"));
+	list_list_view->setColumnAlignment(3,Qt::AlignHCenter);
+      }
+      break;
+      
+    case RDMatrix::LogitekVguest:
+      list_readonly=false;
+      list_list_view->addColumn(tr("ENGINE (Hex)"));
+      list_list_view->setColumnAlignment(2,Qt::AlignHCenter);	
+      list_list_view->addColumn(tr("DEVICE (Hex)"));
+      list_list_view->setColumnAlignment(2,Qt::AlignHCenter);	
+      break;
+      
+    case RDMatrix::StarGuideIII:
+      list_readonly=false;
+      if(list_endpoint==RDMatrix::Input) {
+	list_list_view->addColumn(tr("PROVIDER ID"));
+	list_list_view->setColumnAlignment(2,Qt::AlignHCenter);
+	list_list_view->addColumn(tr("SERVICE ID"));
+	list_list_view->setColumnAlignment(3,Qt::AlignHCenter);
+	list_list_view->addColumn(tr("MODE"));
+	list_list_view->setColumnAlignment(4,Qt::AlignHCenter);
+      }
+      break;
+      
+    case RDMatrix::LiveWire:
+      list_readonly=true;
+      list_list_view->addColumn(tr("NODE"));
+      list_list_view->setColumnAlignment(2,Qt::AlignHCenter);
+      list_list_view->addColumn(tr("#"));
+      list_list_view->setColumnAlignment(3,Qt::AlignHCenter);
+      break;
 
-      case RDMatrix::LogitekVguest:
-	list_list_view->addColumn(tr("ENGINE (Hex)"));
-	  list_list_view->setColumnAlignment(2,Qt::AlignHCenter);	
-	  list_list_view->addColumn(tr("DEVICE (Hex)"));
-	  list_list_view->setColumnAlignment(2,Qt::AlignHCenter);	
-	break;
+    case RDMatrix::SasUsi:
+      list_readonly=true;
+      break;
 
-      case RDMatrix::StarGuideIII:
-	if(list_endpoint==RDMatrix::Input) {
-	  list_list_view->addColumn(tr("PROVIDER ID"));
-	  list_list_view->setColumnAlignment(2,Qt::AlignHCenter);
-	  list_list_view->addColumn(tr("SERVICE ID"));
-	  list_list_view->setColumnAlignment(3,Qt::AlignHCenter);
-	  list_list_view->addColumn(tr("MODE"));
-	  list_list_view->setColumnAlignment(4,Qt::AlignHCenter);
-	}
-	break;
-
-      default:
-	break;
+    default:
+      list_readonly=false;
+      break;
+  }
+  if(!list_readonly) {
+    connect(list_list_view,
+	    SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	    this,
+	    SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
   }
-  connect(list_list_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
 
   //
   //  Edit Button
@@ -144,6 +161,7 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
   button->setFont(bold_font);
   button->setText(tr("&Edit"));
   connect(button,SIGNAL(clicked()),this,SLOT(editData()));
+  button->setDisabled(list_readonly);
 
   //
   //  Ok Button
@@ -217,6 +235,15 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
 	}
 	break;
 
+    case RDMatrix::LiveWire:
+	sql=QString().sprintf("select NUMBER,NAME,NODE_HOSTNAME,NODE_SLOT \
+                               from %s where STATION_NAME=\"%s\" && \
+                               MATRIX=%d order by NUMBER",
+			      (const char *)list_table,
+			      (const char *)list_matrix->station(),
+			      list_matrix->matrix());
+	break;
+
       default:
 	sql=QString().sprintf("select NUMBER,NAME from %s\
                                where STATION_NAME=\"%s\" && \
@@ -226,33 +253,43 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
 			      list_matrix->matrix());
 	break;
   }
-  q=new QSqlQuery(sql);
-  q->first();
-  for(int i=0;i<list_size;i++) {
-    l=new QListViewItem(list_list_view); 
-    l->setText(0,QString().sprintf("%03d",i+1));
-    if(q->isValid()&&(q->value(0).toInt()==(i+1))){
+  q=new RDSqlQuery(sql);
+  if(list_matrix->type()==RDMatrix::LiveWire) {
+    while(q->next()) {
+      l=new QListViewItem(list_list_view); 
+      l->setText(0,QString().sprintf("%05d",q->value(0).toInt()));
       l->setText(1,q->value(1).toString());
-      switch(list_matrix->type()) {
+      l->setText(2,q->value(2).toString());
+      l->setText(3,QString().sprintf("%d",q->value(3).toInt()));
+    }
+  }
+  else {
+    q->first();
+    for(int i=0;i<list_size;i++) {
+      l=new QListViewItem(list_list_view); 
+      l->setText(0,QString().sprintf("%03d",i+1));
+      if(q->isValid()&&(q->value(0).toInt()==(i+1))){
+	l->setText(1,q->value(1).toString());
+	switch(list_matrix->type()) {
 	  case RDMatrix::Unity4000:
 	    if(list_endpoint==RDMatrix::Input) {
 	      l->setText(2,q->value(2).toString());
 	      switch((RDMatrix::Mode)q->value(3).toInt()) {
-		  case RDMatrix::Stereo:
-		    l->setText(3,tr("Stereo"));
-		    break;
-		    
-		  case RDMatrix::Left:
-		    l->setText(3,tr("Left"));
-		    break;
-		    
-		  case RDMatrix::Right:
-		    l->setText(3,tr("Right"));
-		    break;
+		case RDMatrix::Stereo:
+		  l->setText(3,tr("Stereo"));
+		  break;
+		  
+		case RDMatrix::Left:
+		  l->setText(3,tr("Left"));
+		  break;
+		  
+		case RDMatrix::Right:
+		  l->setText(3,tr("Right"));
+		  break;
 	      }
 	    }
 	    break;
-
+	    
 	  case RDMatrix::LogitekVguest:
 	    if(q->value(2).toInt()>=0) {
 	      l->setText(2,QString().sprintf("%04X",q->value(2).toInt()));
@@ -267,7 +304,7 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
 	      l->setText(3,"");
 	    }
 	    break;
-
+	    
 	  case RDMatrix::StarGuideIII:
 	    if(list_endpoint==RDMatrix::Input) {
 	      if(q->value(2).toInt()>=0) {
@@ -277,49 +314,50 @@ ListEndpoints::ListEndpoints(RDMatrix *matrix,RDMatrix::Endpoint endpoint,
 		l->setText(3,q->value(3).toString());
 	      }
 	      switch((RDMatrix::Mode)q->value(4).toInt()) {
-		  case RDMatrix::Stereo:
-		    l->setText(4,tr("Stereo"));
-		    break;
-		    
-		  case RDMatrix::Left:
-		    l->setText(4,tr("Left"));
-		    break;
-		    
-		  case RDMatrix::Right:
-		    l->setText(4,tr("Right"));
-		    break;
+		case RDMatrix::Stereo:
+		  l->setText(4,tr("Stereo"));
+		  break;
+		  
+		case RDMatrix::Left:
+		  l->setText(4,tr("Left"));
+		  break;
+		  
+		case RDMatrix::Right:
+		  l->setText(4,tr("Right"));
+		  break;
 	      }
 	    }
 	    break;
-
+	    
 	  default:
 	    break;
+	}
+	q->next();
       }
-      q->next();
-    }
-    else {
-      switch(list_endpoint) {
+      else {
+	switch(list_endpoint) {
 	  case RDMatrix::Input:
 	    str=QString(tr("Input"));
 	    l->setText(1,QString().sprintf("%s %03d",(const char *)str,i+1));
 	    switch(list_matrix->type()) {
-		case RDMatrix::Unity4000:
-		  l->setText(3,tr("Stereo"));
-		  break;
-
-		case RDMatrix::StarGuideIII:
-		  l->setText(4,tr("Stereo"));
-		  break;
-
-		default:
-		  break;
+	      case RDMatrix::Unity4000:
+		l->setText(3,tr("Stereo"));
+		break;
+		
+	      case RDMatrix::StarGuideIII:
+		l->setText(4,tr("Stereo"));
+		break;
+		
+	      default:
+		break;
 	    }
 	    break;
-
+	    
 	  case RDMatrix::Output:
 	    str=QString(tr("Output"));
 	    l->setText(1,QString().sprintf("%s %03d",(const char *)str,i+1));
 	    break;
+	}
       }
     }
   }
@@ -488,49 +526,50 @@ void ListEndpoints::doubleClickedData(QListViewItem *item,const QPoint &pt,
 
 void ListEndpoints::okData()
 {
-  QListViewItem *item;
-  QString sql;
-  QSqlQuery *q;
-  RDMatrix::Mode mode=RDMatrix::Stereo;
-  int enginenum;
-  int devicenum;
-  int modecol=3;
-
-  if(list_matrix->type()==RDMatrix::StarGuideIII) {
-    modecol=4;
-  }
-  for(int i=0;i<list_size;i++) {
-    item=list_list_view->findItem(QString().sprintf("%03d",i+1),0);
-    if(item->text(modecol).lower()==QString(tr("stereo"))) {
-      mode=RDMatrix::Stereo;
+  if(!list_readonly) {
+    QListViewItem *item;
+    QString sql;
+    RDSqlQuery *q;
+    RDMatrix::Mode mode=RDMatrix::Stereo;
+    int enginenum;
+    int devicenum;
+    int modecol=3;
+    
+    if(list_matrix->type()==RDMatrix::StarGuideIII) {
+      modecol=4;
     }
-    if(item->text(modecol).lower()==QString(tr("left"))) {
-      mode=RDMatrix::Left;
-    }
-    if(item->text(modecol).lower()==QString(tr("right"))) {
-      mode=RDMatrix::Right;
-    }
-    sql=QString().sprintf("select ID from %s where\
-                           STATION_NAME=\"%s\" && \
-                           MATRIX=%d && \
-                           NUMBER=%d",
-			  (const char *)list_table,
-			  (const char *)list_matrix->station(),
-			  list_matrix->matrix(),
-			  i+1);
-    q=new QSqlQuery(sql);
-    if(!q->first()) {
-      delete q;
-      sql=QString().sprintf("insert into %s set STATION_NAME=\"%s\",\
-                             MATRIX=%d,\
-                             NUMBER=%d,\
-                             NAME=\"%s\"",
+    for(int i=0;i<list_size;i++) {
+      item=list_list_view->findItem(QString().sprintf("%03d",i+1),0);
+      if(item->text(modecol).lower()==QString(tr("stereo"))) {
+	mode=RDMatrix::Stereo;
+      }
+      if(item->text(modecol).lower()==QString(tr("left"))) {
+	mode=RDMatrix::Left;
+      }
+      if(item->text(modecol).lower()==QString(tr("right"))) {
+	mode=RDMatrix::Right;
+      }
+      sql=QString().sprintf("select ID from %s where\
+                             STATION_NAME=\"%s\" && \
+                             MATRIX=%d && \
+                             NUMBER=%d",
 			    (const char *)list_table,
 			    (const char *)list_matrix->station(),
 			    list_matrix->matrix(),
-			    i+1,
-			    (const char *)item->text(1));
-      switch(list_matrix->type()) {
+			    i+1);
+      q=new RDSqlQuery(sql);
+      if(!q->first()) {
+	delete q;
+	sql=QString().sprintf("insert into %s set STATION_NAME=\"%s\",\
+                               MATRIX=%d,\
+                               NUMBER=%d,\
+                               NAME=\"%s\"",
+			      (const char *)list_table,
+			      (const char *)list_matrix->station(),
+			      list_matrix->matrix(),
+			      i+1,
+			      (const char *)item->text(1));
+	switch(list_matrix->type()) {
 	  case RDMatrix::Unity4000:
 	    if(list_endpoint==RDMatrix::Input) {
 	      sql+=QString().sprintf(",FEED_NAME=\"%s\",CHANNEL_MODE=%d",
@@ -538,7 +577,7 @@ void ListEndpoints::okData()
 				     mode);
 	    }
 	    break;
-
+	    
 	  case RDMatrix::LogitekVguest:
 	    if(item->text(2).isEmpty()) {
 	      sql+=",ENGINE_NUM=-1";
@@ -555,7 +594,7 @@ void ListEndpoints::okData()
 				     item->text(3).toInt(NULL,16));
 	    }
 	    break;
-
+	    
 	  case RDMatrix::StarGuideIII:
 	    if(item->text(2).isEmpty()) {
 	      sql+=",ENGINE_NUM=-1";
@@ -575,16 +614,16 @@ void ListEndpoints::okData()
 	      sql+=QString().sprintf(",CHANNEL_MODE=%d",mode);
 	    }
 	    break;
-
+	    
 	  default:
 	    break;
+	}
+	q=new RDSqlQuery(sql);
+	delete q;
       }
-      q=new QSqlQuery(sql);
-      delete q;
-    }
-    else {
-      delete q;
-      switch(list_matrix->type()) {
+      else {
+	delete q;
+	switch(list_matrix->type()) {
 	  case RDMatrix::Unity4000:
 	    if(list_endpoint==RDMatrix::Input) {
 	      sql=QString().sprintf("update %s set NAME=\"%s\",\
@@ -602,7 +641,7 @@ void ListEndpoints::okData()
 				    i+1);
 	    }
 	    break;
-
+	    
 	  case RDMatrix::LogitekVguest:
 	    if(item->text(2).isEmpty()) {
 	      enginenum=-1;
@@ -629,7 +668,7 @@ void ListEndpoints::okData()
 				  list_matrix->matrix(),
 				  i+1);
 	    break;
-
+	    
 	  case RDMatrix::StarGuideIII:
 	    if(list_endpoint==RDMatrix::Input) {
 	      if(item->text(2).isEmpty()) {
@@ -660,7 +699,7 @@ void ListEndpoints::okData()
 				    i+1);
 	    }
 	    break;
-
+	    
 	  default:
 	    sql=QString().sprintf("update %s set NAME=\"%s\" where\
                                    STATION_NAME=\"%s\" && \
@@ -672,9 +711,10 @@ void ListEndpoints::okData()
 				  list_matrix->matrix(),
 				  i+1);
 	    break;
+	}
+	q=new RDSqlQuery(sql);
+	delete q;
       }
-      q=new QSqlQuery(sql);
-      delete q;
     }
   }
   done(0);
