@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.cpp,v 1.188.2.3 2008-11-07 12:58:17 fredg Exp $
+//      $Id: log_play.cpp,v 1.188.2.14 2009/03/17 13:11:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,6 +32,7 @@
 #include <globals.h>
 
 LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
+		 std::vector<RLMHost *> *rlm_hosts,
 		 QObject *parent,const char *name)
   : QObject(parent,name),RDLogEvent(logname)
 {
@@ -41,6 +42,7 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_cae=cae;
   play_log=NULL;
   play_id=id;
+  play_rlm_hosts=rlm_hosts;
   play_onair_flag=false;
   play_segue_length=rdairplay_conf->segueLength()+1;
   play_trans_length=rdairplay_conf->transLength()+1;
@@ -50,7 +52,6 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_running=false;
   play_next_line=0;
   play_post_time=QTime();
-  play_start_time=QTime();
   play_post_offset=-1;
   play_active_line=-1;
   play_active_trans=RDLogLine::Play;
@@ -67,7 +68,6 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   for(int i=0;i<2;i++) {
     play_card[i]=0;
     play_port[i]=0;
-    play_prev_logline[i]=NULL;
   }
   for(int i=0;i<RD_MAX_STREAMS;i++) {
     play_deck[i]=new RDPlayDeck(play_cae,0,this);
@@ -79,6 +79,10 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_nownext_address=rdairplay_conf->udpAddress(id);
   play_nownext_port=rdairplay_conf->udpPort(id);
   play_nownext_rml=rdairplay_conf->logRml(id);
+  play_now_cartnum=0;
+  play_next_cartnum=0;
+  play_prevnow_cartnum=0;
+  play_prevnext_cartnum=0;
 
   //
   // Macro Cart Decks
@@ -121,11 +125,6 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
 }
 
 
-LogPlay::~LogPlay()
-{
-}
-
-
 QString LogPlay::serviceName() const
 {
   if(play_svc_name.isEmpty()) {
@@ -210,6 +209,18 @@ void LogPlay::setSegueLength(int len)
 }
 
 
+void LogPlay::setNowCart(unsigned cartnum)
+{
+  play_now_cartnum=cartnum;
+}
+
+
+void LogPlay::setNextCart(unsigned cartnum)
+{
+  play_next_cartnum=cartnum;
+}
+
+
 bool LogPlay::play(int line,RDLogLine::StartSource src,
 		   int mport,bool skip_meta)
 {
@@ -366,11 +377,11 @@ void LogPlay::duckVolume(int level,int fade,int mport)
 
 void LogPlay::makeNext(int line,bool refresh_status)
 {
-  LogLine(RDConfig::LogDebug,QString().sprintf("LogPlay::makeNext(%d)",line));
   play_next_line=line;
   if(refresh_status) {
     RefreshEvents(line,LOGPLAY_LOOKAHEAD_EVENTS);
   }
+  SendNowNext();
   emit nextEventChanged(line);
   emit transportChanged();
 }
@@ -452,13 +463,9 @@ bool LogPlay::refresh()
   int next_line=-1;
   int next_id=-1;
   int current_id=-1;
-
   int lines[TRANSPORT_QUANTITY];
   int running;
 
-  if(!play_refreshable) {
-    return false;
-  }
   if(play_macro_running) {
     play_refresh_pending=true;
     return true;
@@ -482,7 +489,7 @@ bool LogPlay::refresh()
   //
   if(nextEvent()!=NULL) {   //End of the log?
     next_id=nextEvent()->id();
-    }
+  }
 
   //
   // Get Running Events
@@ -491,11 +498,11 @@ bool LogPlay::refresh()
   for(int i=0;i<running;i++) {
     if(lines[i]==play_next_line-1) {
       current_id=logLine(lines[i])->id();
-      }
     }
+  }
   if(running>0 && next_id==-1) {                  //Last Event of Log Running?
     current_id=logLine(lines[running-1])->id();
-    }
+  }
 
   //
   // Pass 1: Finished or Active Events
@@ -752,6 +759,7 @@ void LogPlay::remove(int line,int num_lines,bool update,bool preserv_custom_tran
     if((logline=logLine(i))!=NULL) {
       if((playdeck=(RDPlayDeck *)logline->playDeck())!=NULL) {
 	playdeck->clear();
+	FreePlayDeck(playdeck);
       }
     }
   }
@@ -1159,9 +1167,9 @@ QTime LogPlay::nextStop() const
 }
 
 
-bool LogPlay::running()
+bool LogPlay::running(bool include_paused)
 {
-  if(runningEvents(NULL)==0) {
+  if(runningEvents(NULL,include_paused)==0) {
     return false;
   }
   return true;
@@ -1456,10 +1464,15 @@ void LogPlay::macroStoppedData()
 
 void LogPlay::timescalingSupportedData(int card,bool state)
 {
-  play_timescaling_supported[card]=state;
-  if(play_timescaling_supported[play_card[0]]&&
-     play_timescaling_supported[play_card[1]]) {
-    play_timescaling_available=true;
+  if(card>=0) {
+    play_timescaling_supported[card]=state;
+    if(play_timescaling_supported[play_card[0]]&&
+       play_timescaling_supported[play_card[1]]) {
+      play_timescaling_available=true;
+    }
+    else {
+      play_timescaling_available=false;
+    }
   }
   else {
     play_timescaling_available=false;
@@ -2133,91 +2146,21 @@ void LogPlay::UpdatePostPoint(int line)
 {
   int post_line=-1;
   QTime post_time;
-  QTime start_time;
   int offset=0;
 
-  if(line==size()) {
-    play_post_time=QTime();
-    play_start_time=QTime();
+  if((line<size())&&(play_trans_line>=0)&&(play_trans_line<size())) {
+    post_line=play_trans_line;
+    post_time=logLine(post_line)->startTime(RDLogLine::Logged);
+    offset=length(line,post_line)-QTime::currentTime().msecsTo(post_time);
   }
-  else {
-    post_line=NextPostPoint(line,&start_time,&offset);
-    if(post_line<0) {
-      post_time=QTime();
-    }
-    else {
-      post_time=logLine(post_line)->startTime(RDLogLine::Logged);
-    }
-  }
-
-  /*
-  printf("UpdatePostPoint Line: %d  Post: %s  Actual: %s  Offset: %d\n",
-	 post_line,(const char *)post_time.toString("hh:mm:ss"),
-	 (const char *)start_time.toString("hh:mm:ss"),offset); 
-  */
-  if((post_time!=play_post_time)||(start_time!=play_start_time)||
-    (offset!=play_post_offset)) {
+  if((post_time!=play_post_time)||(offset!=play_post_offset)) {
     play_post_time=post_time;
-    play_start_time=start_time;
     play_post_offset=offset;
-    emit postPointChanged(play_post_time,play_start_time,offset);
+    emit postPointChanged(play_post_time,offset,post_line>=line,running(false));
   }
 }
 
 
-int LogPlay::NextPostPoint(int line,QTime *start,int *offset)
-{
-  *offset=0;
-  RDLogLine *logline;
-  if(running()) {
-    for(int i=line;i<size();i++) {
-      if((logline=logLine(i))!=NULL) {
-	if(status(i)==RDLogLine::Playing) {
-	  *start=logline->startTime(RDLogLine::Actual);
-	  *offset=logline->segueLength(nextTrans(i));
-	}
-	else {
-	  if(logline->timeType()!=RDLogLine::Hard) {
-	    *offset+=logLine(i)->segueLength(nextTrans(i));
-	  }
-	  else {
-
-	    if((logline->startTime(RDLogLine::Logged)>
-		QTime::currentTime().addMSecs(rdstation_conf->timeOffset()))) {
-	      return i;
-	    }
-	  }
-	}
-      }
-    }
-    rdairplay_conf->setLogRunning(play_id,true);
-  }
-  else {
-    if((logline=logLine(play_next_line))!=NULL) {
-      *start=logline->startTime(RDLogLine::Actual);
-    }
-    for(int i=play_next_line;i<size();i++) {
-      if((logline=logLine(i))!=NULL) {
-	if(logline->status()==RDLogLine::Scheduled) {
-	  if(logline->timeType()!=RDLogLine::Hard) {
-	    *offset+=logLine(i)->segueLength(nextTrans(i));
-	  }
-	  else {
-	    if((logline->startTime(RDLogLine::Logged)>
-		QTime::currentTime().addMSecs(rdstation_conf->timeOffset()))) {
-	      return i;
-	    }
-	  }
-	}
-      }
-    }
-    rdairplay_conf->setLogRunning(play_id,false);
-  }
-  *start=QTime();
-  return -1;
-}
-
-
 void LogPlay::AdvanceActiveEvent()
 {
   int line=-1;
@@ -2271,6 +2214,9 @@ QString LogPlay::GetPortName(int card,int port)
 
 void LogPlay::SetTransTimer(QTime current_time,bool stop)
 {
+  int next_line=-1;
+  QTime next_time=QTime(23,59,59);
+
   if(current_time.isNull()) {
     current_time=QTime::currentTime();
   }
@@ -2288,15 +2234,17 @@ void LogPlay::SetTransTimer(QTime current_time,bool stop)
       if((logline->timeType()==RDLogLine::Hard)&&
 	 ((logline->status()==RDLogLine::Scheduled)||
 	  (logline->status()==RDLogLine::Auditioning))&&
-	 (logline->startTime(RDLogLine::Logged)>current_time)) {
-	play_trans_line=i;
-	play_trans_timer->
-	  start(current_time.msecsTo(logline->startTime(RDLogLine::Logged)),
-		true);
-	return;
+	 (logline->startTime(RDLogLine::Logged)>current_time)&&
+	 (logline->startTime(RDLogLine::Logged)<=next_time)) {
+	next_time=logline->startTime(RDLogLine::Logged);
+	next_line=i;
       }
     }
   }
+  if(next_line>=0) {
+    play_trans_line=next_line;
+    play_trans_timer->start(current_time.msecsTo(next_time),true);
+  }
 }
 
 
@@ -2506,144 +2454,6 @@ void LogPlay::RefreshEvents(int line,int line_quan,bool force_update)
 }
 
 
-void LogPlay::SendNowNext()
-{
-  QTime end_time;
-  QTime time;
-  int now_line=-1;
-  RDLogLine *logline[2];
-  RDLogLine *ll;
-
-  //
-  // Get NOW PLAYING Event
-  //
-  if(play_nownext_address.isNull()&&play_nownext_rml.isEmpty()) {
-    return;
-  }
-  QString cmd=play_nownext_string;
-  int lines[TRANSPORT_QUANTITY];
-  int running=runningEvents(lines,false);
-  for(int i=0;i<running;i++) {
-    if((time=logLine(lines[i])->startTime(RDLogLine::Actual).
-	addMSecs(logLine(lines[i])->effectiveLength()))>end_time) {
-      end_time=time;
-      now_line=lines[i];
-    }
-  }
-  if((now_line>=0)&&(logLine(now_line)->nowNextEnabled())) {
-    logline[0]=logLine(now_line);
-  }
-  else {
-    logline[0]=NULL;
-  }
-
-  //
-  // Get NEXT Event
-  //
-  logline[1]=NULL;
-  for(int i=nextLine();i<size();i++) {
-    if((ll=logLine(i))!=NULL) {
-      if((ll->status()==RDLogLine::Scheduled)&&
-	 logLine(i)->nowNextEnabled()) {
-	logline[1]=logLine(i);
-	i=size();
-      }
-    }
-  }
-
-  //
-  // Process and Send It
-  //
-  if((play_prev_logline[0]==logline[0])&&(play_prev_logline[1]==logline[1])) {
-    return;
-  }
-  play_prev_logline[0]=logline[0];
-  play_prev_logline[1]=logline[1];
-  ResolveNowNext(&cmd,logline);
-  play_nownext_socket->
-    writeBlock(cmd,cmd.length(),play_nownext_address,play_nownext_port);
-
-  cmd=play_nownext_rml;
-  ResolveNowNext(&cmd,logline);
-  rdevent_player->exec(cmd);
-}
-
-
-void LogPlay::ResolveNowNext(QString *str,RDLogLine **loglines)
-{
-  //
-  // NOW PLAYING Event
-  //
-  if(loglines[0]!=NULL) {
-    str->replace("%n",QString().sprintf("%06u",loglines[0]->cartNumber()));
-    str->replace("%h",QString().sprintf("%d",loglines[0]->effectiveLength()));
-    str->replace("%g",loglines[0]->groupName());
-    str->replace("%t",loglines[0]->title());
-    str->replace("%a",loglines[0]->artist());
-    str->replace("%l",loglines[0]->album());
-    str->replace("%y",loglines[0]->year().toString("yyyy"));
-    str->replace("%b",loglines[0]->label());
-    str->replace("%c",loglines[0]->client());
-    str->replace("%e",loglines[0]->agency());
-    str->replace("%m",loglines[0]->composer());
-    str->replace("%p",loglines[0]->publisher());
-    str->replace("%u",loglines[0]->userDefined());
-  }
-  else {   // No NOW PLAYING Event
-    str->replace("%n","");
-    str->replace("%h","");
-    str->replace("%g","");
-    str->replace("%t","");
-    str->replace("%a","");
-    str->replace("%l","");
-    str->replace("%y","");
-    str->replace("%b","");
-    str->replace("%c","");
-    str->replace("%e","");
-    str->replace("%m","");
-    str->replace("%p","");
-    str->replace("%u","");
-  }
-
-  //
-  // NEXT Event
-  //
-  if(loglines[1]!=NULL) {
-    str->replace("%N",QString().sprintf("%06u",loglines[1]->cartNumber()));
-    str->replace("%H",QString().sprintf("%d",loglines[1]->effectiveLength()));
-    str->replace("%G",loglines[1]->groupName());
-    str->replace("%T",loglines[1]->title());
-    str->replace("%A",loglines[1]->artist());
-    str->replace("%L",loglines[1]->album());
-    str->replace("%Y",loglines[1]->year().toString("yyyy"));
-    str->replace("%B",loglines[1]->label());
-    str->replace("%C",loglines[1]->client());
-    str->replace("%E",loglines[1]->agency());
-    str->replace("%M",loglines[1]->composer());
-    str->replace("%P",loglines[1]->publisher());
-    str->replace("%U",loglines[1]->userDefined());
-  }
-  else {   // No NEXT Event
-    str->replace("%N","");
-    str->replace("%H","");
-    str->replace("%G","");
-    str->replace("%T","");
-    str->replace("%A","");
-    str->replace("%L","");
-    str->replace("%Y","");
-    str->replace("%B","");
-    str->replace("%C","");
-    str->replace("%E","");
-    str->replace("%M","");
-    str->replace("%P","");
-    str->replace("%U","");
-  }
-  str->replace("%%","%");
-  str->replace("%r","\n");
-  str->replace("%R","\r\n");
-}
-
-
 void LogPlay::Playing(int id)
 {
   RDLogLine *logline;
