@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.cpp,v 1.171.2.5 2008-12-03 20:24:42 fredg Exp $
+//      $Id: rdairplay.cpp,v 1.171.2.7 2009/02/12 15:18:04 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -106,6 +106,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   QPixmap *pm=NULL;
   QPainter *pd=NULL;
   air_refresh_pixmap=NULL;
+  air_panel=NULL;
 
   //
   // Ensure Single Instance
@@ -914,7 +915,6 @@ void MainWidget::logRenamedData(int log)
   if(logname.isEmpty()) {
     labelname="--";
   }
-
   switch(log) {
       case 0:
 	str=QString(tr("Main Log"));
@@ -965,15 +965,19 @@ void MainWidget::logReloadedData(int log)
 			(const char *)air_log[0]->logName().
 			left(air_log[0]->logName().length()-4)));
 	if(air_log[0]->logName().isEmpty()) {
-          if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-            air_panel->setSvcName(
+	  if(air_panel!=NULL) {
+	    if(rdstation_conf->broadcastSecurity()==RDStation::UserSec) {
+	      air_panel->setSvcName(
                 rduser->serviceCheckDefault( rdairplay_conf->defaultSvc() ) );
-          } else { // RDStation::HostSec
-            air_panel->setSvcName(rdairplay_conf->defaultSvc());
-          }
+	    } else { // RDStation::HostSec
+	      air_panel->setSvcName(rdairplay_conf->defaultSvc());
+	    }
+	  }
 	}
 	else {
-	  air_panel->setSvcName(air_log[0]->serviceName());
+	  if(air_panel!=NULL) {
+	    air_panel->setSvcName(air_log[0]->serviceName());
+	  }
 	}
 	break;
 
@@ -1070,7 +1074,9 @@ void MainWidget::userData()
     for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
       air_log[i]->setDefaultServiceName(default_svcname);
     }
-    air_panel->setSvcName(default_svcname);
+    if(air_panel!=NULL) {
+      air_panel->setSvcName(default_svcname);
+    }
   }
 
 }
@@ -1311,20 +1317,26 @@ void MainWidget::selectClickedData(unsigned cartnum,int row,int col)
 	break;
 
       case StartButton::CopyTo:
-        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
-                             row,col,air_add_cart);
+	if(air_panel!=NULL) {
+	  air_panel->setButton(air_panel->currentType(),
+			       air_panel->currentNumber(),row,col,air_add_cart);
+	}
 	SetActionMode(StartButton::Stop);
 	break;
 
       case StartButton::AddTo:
-        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
-                             row,col,air_add_cart);
+	if(air_panel!=NULL) {
+	  air_panel->setButton(air_panel->currentType(),
+			       air_panel->currentNumber(),row,col,air_add_cart);
+	}
 	SetActionMode(StartButton::Stop);
 	break;
 
       case StartButton::DeleteFrom:
-        air_panel->setButton(air_panel->currentType(),air_panel->currentNumber(),
-                             row,col,0);
+	if(air_panel!=NULL) {
+	  air_panel->setButton(air_panel->currentType(),
+			       air_panel->currentNumber(),row,col,0);
+	}
 	SetActionMode(StartButton::Stop);
 	break;
 
@@ -1737,7 +1749,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::Normal);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::Normal);
-	air_panel->setActionMode(RDAirPlayConf::Normal);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::Normal);
+	}
 
 	break;
 
@@ -1788,7 +1802,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::Normal);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::Normal);
-	air_panel->setActionMode(RDAirPlayConf::Normal);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::Normal);
+	}
 	if(rdcart_dialog->exec(&air_add_cart,RDCart::All,0,0)==0) {
 	  SetActionMode(StartButton::AddTo);
 	}
@@ -1807,7 +1823,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::AddTo,&air_add_cart);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::AddTo);
-	air_panel->setActionMode(RDAirPlayConf::AddTo);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::AddTo);
+	}
 	break;
 
       case StartButton::DeleteFrom:
@@ -1820,7 +1838,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::DeleteFrom);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::DeleteFrom);
-	air_panel->setActionMode(RDAirPlayConf::DeleteFrom);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::DeleteFrom);
+	}
 	break;
 
       case StartButton::MoveFrom:
@@ -1833,7 +1853,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::MoveFrom);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::MoveFrom);
-	air_panel->setActionMode(RDAirPlayConf::MoveFrom);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::MoveFrom);
+	}
 	break;
 
       case StartButton::MoveTo:
@@ -1846,7 +1868,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::MoveTo);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::MoveTo);
-	air_panel->setActionMode(RDAirPlayConf::MoveTo);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::MoveTo);
+	}
 	break;
 
       case StartButton::CopyFrom:
@@ -1859,7 +1883,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::CopyFrom);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::CopyFrom);
-	air_panel->setActionMode(RDAirPlayConf::CopyFrom);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::CopyFrom);
+	}
 	break;
 
       case StartButton::CopyTo:
@@ -1872,7 +1898,9 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  air_log_list[i]->setActionMode(RDAirPlayConf::CopyTo);
 	}
 	air_button_list->setActionMode(RDAirPlayConf::CopyTo);
-	air_panel->setActionMode(RDAirPlayConf::CopyTo);
+	if(air_panel!=NULL) {
+	  air_panel->setActionMode(RDAirPlayConf::CopyTo);
+	}
 	break;
 
       default:
