@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cast.h,v 1.4 2007/11/29 19:29:19 fredg Exp $
+//      $Id: edit_cast.h,v 1.4.2.1 2009/01/30 19:51:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,6 +49,7 @@ class EditCast : public QDialog
 
  private slots:
   void expirationSelectedData(int state);
+  void effectiveSelectData();
   void expirationSelectData();
   void reportData();
   void okData();
@@ -69,6 +70,7 @@ class EditCast : public QDialog
   QLabel *cast_item_expiration_label;
   QPushButton *cast_item_expiration_button;
   QDateTimeEdit *cast_item_expiration_edit;
+  QDateTimeEdit *cast_item_effective_edit;
   QButtonGroup *cast_item_status_group;
   std::vector<QString> cast_aux_varnames;
   std::vector<QLineEdit *> cast_aux_edits;
